Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
var NoOp = Func(func(format string, args ...interface{}) {})
NoOp logger
var Std = Func(func(format string, args ...interface{}) { stdlog.Printf(format, args...) })
Std logger sends to std default logger directly
Functions ¶
Types ¶
type Func ¶
type Func func(format string, args ...interface{})
Func type is an adapter to allow the use of ordinary functions as Logger.
type L ¶
type L interface {
Logf(format string, args ...interface{})
}
L defines minimal interface used to log things
type Logger ¶
type Logger struct {
// contains filtered or unexported fields
}
Logger provided simple logger with basic support of levels. Thread safe
func New ¶
New makes new leveled logger. Accepts dbg flag turing on info about the caller and allowing DEBUG messages/ Two writers can be passed optionally - first for out and second for err
Click to show internal directories.
Click to hide internal directories.